@@ -1,6 +1,5 @@
-package Getopt::Complete::LazyOptions;
 
-our $VERSION = $Getopt::Complete::VERSION;
+package Getopt::Complete::LazyOptions;
 
 our $AUTOLOAD;
 
@@ -32,7 +31,7 @@ sub AUTOLOAD {
             $spec = eval $data;
         }
         else {
-#            print STDERR ">> redo $class!\n";
+            print STDERR ">> redo $class!\n";
             local $ENV{GETOPT_COMPLETE_CACHE} = 1;
             eval "use $class";
             die $@ if $@;
@@ -66,10 +65,6 @@ sub AUTOLOAD {
 
 Getopt::Complete::LazyOptions - internal object used as a placeholder for unprocessed options
 
-=head1 VERSION
-
-This document describes Getopt::Complete::LazyOptions 0.23.
-
 =head1 SYNOPSIS
 
     use Getopt::Complete (
